Class: CABinCmp
- Inherits:
-
Object
- Object
- CABinCmp
- Defined in:
- yard-stubs/carray_lazy.rb
Copy and conversion collapse
-
#copy ⇒ CArray
Evaluates the expression and returns the result as a new entity.
-
#to_ca ⇒ CArray
Evaluates the expression and returns the result as a new entity.